<?php
/*
  Plugin Name: Tickera - Event Stats Shortcode
  Plugin URI: http://tickera.com/
  Description: Displays number of sold/left tickets for the upcoming / past events with [tc_custom_event_stats type="upcoming"] or [tc_custom_event_stats type="past"] shortcodes and using the event id with [tc_custom_event_stats event_id="123"]
  Author: Tickera.com
  Author URI: http://tickera.com/
  Version: 1.0
  TextDomain: tc
 * 
 */

add_shortcode('tc_custom_event_stats', 'tc_custom_event_stats');

function tc_custom_event_stats($atts)
{
    extract(
        shortcode_atts(
            array(
                'type' => 'upcoming', //upcoming or past
                'event_id' => '',
            ), $atts
        )
    );

    ob_start();

    if ($event_id == null) {

        if ($type == 'past') {//past events query
            $args = array(
                'post_type' => 'tc_events',
                'posts_per_page' => -1,
                'meta_query' => array(
                    array(
                        'key' => 'event_date_time',
                        'value' => date('Y-m-d h:i'),
                        'type' => 'DATETIME',
                        'compare' => '<='
                    ),
                    'orderby' => 'event_date_time',
                ),
                'order' => 'ASC',
                'orderby' => 'meta_value',
                'post_status' => 'publish'
            );
        } else {//upcoming events query
            $args = array(
                'post_type' => 'tc_events',
                'posts_per_page' => -1,
                'meta_query' => array(
                    array(
                        'key' => 'event_date_time',
                        'value' => date('Y-m-d h:i'),
                        'type' => 'DATETIME',
                        'compare' => '>='
                    ),
                    'orderby' => 'event_date_time',
                ),
                'order' => 'ASC',
                'orderby' => 'meta_value',
                'post_status' => 'publish'
            );
        }

        $the_query = new WP_Query($args);
        global $tc; //required in order to use get_cart_currency_and_format method from core of Tickera

        if ($the_query->have_posts()) {
            while ($the_query->have_posts()) {
                $the_query->the_post();

                $event = new TC_Event(get_the_ID()); //create event object
                $event_location = $event->details->event_location;
                $event_date = do_shortcode('[tc_event_date event_id="' . get_the_ID() . '"]'); //shortcode from Tickera which shows full date of the event
                ?>
                <div class="tc-single-event">
                    <h3>
                        <a href="<?php the_permalink(); ?>">
                            <?php echo $event->details->post_title; ?>
                        </a>
                        </br>
                        <span class="tc_event_date_title_front"><i class="fa fa-clock-o"></i><?php echo $event_date; ?> </span> </br>
                        <?php if (!empty($event_location)) {//show only if the event location isn't empty ?>
                            <span class="tc_event_location_title_front"><i class="fa fa-map-marker"></i><?php echo $event_location; ?></span>
                        <?php } ?>
                    </h3>

                    <?php echo 'Event tickets sold: ' . do_shortcode('[event_tickets_sold]') ?><br/>
                    <?php echo 'Event tickets left: ' . do_shortcode('[event_tickets_left]') ?><br/>
                    Ticket types stats:<br/><br/>
                    <?php
                    $ticket_types = $event->get_event_ticket_types(); //get all ticket types IDs associated with the event
                    if (count($ticket_types) > 0) {
                        ?>
                        <table>
                            <tr>
                                <th>Ticket Type</th>
                                <th>Count Sold</th>
                                <th>Count Left</th>
                                <th>Revenue</th>
                            </tr>
                            <?php
                            foreach ($ticket_types as $ticket_type_id) {
                                $ticket_type = new TC_Ticket($ticket_type_id); //create ticket type object so we can use its methods and properties
                                $count_left = $ticket_type->get_tickets_quantity_left();
                                $count_sold = $ticket_type->get_number_of_sold_tickets();
                                $price = $ticket_type->details->price_per_ticket;
                                ?>
                                <tr>
                                    <td><?php echo $ticket_type->details->post_title; ?></td>
                                    <td><?php echo $count_sold; ?></td>
                                    <td><?php echo $count_left == 9999 ? '∞' : $count_left; //make sure to put a "∞" for qty 9999 because it means unlimited    ?></td>
                                    <td><?php echo $tc->get_cart_currency_and_format($count_sold * $price); ?></td>
                                </tr>
                                <?php
                            }
                            ?>
                        </table>
                        <?php
                    } else {
                        echo 'Stats are not available since there are no ticket types associated with this event';
                    }
                    ?>
                    <hr/>
                </div>

                <?php
            }
        } else {
            ?>
            <p><?php echo 'There are currently no ' . $type . ' events available.'; ?> </p>
            <?php
        }
        /* Restore original Post Data */
        wp_reset_postdata();
        $content = ob_get_clean();

        return $content;
    }
    else {

        ob_start();

        $args = array(
            'p' => $event_id,
            'post_type' => 'tc_events',
            //'posts_per_page' => -1,
            'post_status' => 'publish'
        );


        $the_query = new WP_Query($args);
        global $tc;

        if ($the_query->have_posts()) {
            while ($the_query->have_posts()) {
                $the_query->the_post();

                $event = new TC_Event(get_the_ID()); //create event object
                $event_location = $event->details->event_location;
                $event_date = do_shortcode('[tc_event_date event_id="' . get_the_ID() . '"]');
                ?>
                <div class="tc-single-event">
                    <h3>
                        <a href="<?php the_permalink(); ?>">
                            <?php echo $event->details->post_title; ?>
                        </a>
                        </br>
                        <span class="tc_event_date_title_front"><i class="fa fa-clock-o"></i><?php echo $event_date; ?> </span> </br>
                        <?php if (!empty($event_location)) {//show only if the event location isn't empty ?>
                            <span class="tc_event_location_title_front"><i class="fa fa-map-marker"></i><?php echo $event_location; ?></span>
                        <?php } ?>
                    </h3>
                    <?php echo 'Event tickets sold: ' . do_shortcode('[event_tickets_sold]') ?><br/>
                    <?php echo 'Event tickets left: ' . do_shortcode('[event_tickets_left]') ?><br/>
                    Ticket types stats:<br /><br />
                    <?php
                    $ticket_types = $event->get_event_ticket_types(); //get all ticket types IDs associated with the event
                    if (count($ticket_types) > 0) {
                        ?>
                        <table>
                            <tr>
                                <th>Ticket Type</th>
                                <th>Count Sold</th>
                                <th>Count Left</th>
                                <th>Revenue</th>


                            </tr>
                            <?php
                            foreach ($ticket_types as $ticket_type_id) {
                                $ticket_type = new TC_Ticket($ticket_type_id); //create ticket type object so we can use its methods and properties
                                $count_left = $ticket_type->get_tickets_quantity_left();
                                $count_sold = $ticket_type->get_number_of_sold_tickets();
                                $price = $ticket_type->details->price_per_ticket;
                                ?>
                                <tr>
                                    <td><?php echo $ticket_type->details->post_title; ?></td>
                                    <td><?php echo $count_sold; ?></td>
                                    <td><?php echo $count_left == 9999 ? '∞' : $count_left; //make sure to put a "∞" for qty 9999 because it means unlimited    ?></td>
                                    <td><?php echo $tc->get_cart_currency_and_format($count_sold * $price); ?></td>
                                </tr>
                                <?php
                            }
                            ?>
                        </table>
                        <?php
                    } else {
                        echo 'Stats are not available since there are no ticket types associated with this event';
                    }
                    ?>
                    <hr />
                </div>

                <?php
            }
        } else {
            ?>
            <p><?php echo 'There are no events available.'; ?> </p>
            <?php
        }
        /* Restore original Post Data */
        wp_reset_postdata();
        $content = ob_get_clean();

        return $content;
    }
}
